@@ -7,7 +7,7 @@ use strict;
 
 use PPM;
 
-$PPM::VERSION = '0.01_01';
+$PPM::VERSION = "2.1.1";
 
 my %help;
 
@@ -55,23 +55,16 @@ if ($#ARGV == 0 && $ARGV[0] eq 'genconfig') {
     exit 0;
 }
 
-if ($#ARGV == 0 && $ARGV[0] eq 'getconfig') {
-    print $PPM::PPMdat;
-    exit 0;
-}
-
 my %options = PPM::GetPPMOptions();
 my $location;
 
-my $moremsg = "[Press return to continue or 'q' to quit] ";
+my $moremsg = "[Press return to continue]";
 my $interactive = 0;
 
 my %repositories = PPM::ListOfRepositories();
 
 my $prefix_pattern = $^O eq "MSWin32" ? '(--|-|\+|/)' : '(--|-|\+)';
 
-$PPM::PPMShell = 1;
-
 Getopt::Long::Configure("prefix_pattern=$prefix_pattern");
 
 if ($#ARGV == -1 || ($#ARGV == 0 && $ARGV[0] =~ /^${prefix_pattern}location/)) {
@@ -86,6 +79,7 @@ if ($#ARGV == -1 || ($#ARGV == 0 && $ARGV[0] =~ /^${prefix_pattern}location/)) {
         last unless defined ($_ = <> );
         chomp;
         s/^\s+//;
+        s/::/-/g;
         @ARGV = split(/\s+/, $_);
         next unless @ARGV;
         # exit/quit
@@ -104,10 +98,6 @@ sub exec_command
 {
     my $cmd = lc shift @ARGV;
 
-    for (@ARGV) {
-        s/::/-/g;
-    }
-
     # help
     if (command($cmd, "|help")) {
         help(@ARGV);
@@ -155,23 +145,13 @@ sub exec_command
             print "Package not specified.\n";
             return 1;
         }
-
-        my %installed = InstalledPackageProperties();
         foreach my $package (@ARGV) {
             $package =~ s/::/-/g;
-            if (my $pkg = (grep {/^$package$/i} keys %installed)[0]) {
-                my $version = $installed{$pkg}{'VERSION'};
-                $version =~ s/(,0)*$//;
-                $version =~ tr/,/./;
-                print "Version $version of '$pkg' is already installed.\n" .
-                      "Remove it, or use 'verify --upgrade $pkg'.\n";
-                next;
-            }
-            elsif ($interactive && $options{'CONFIRM'}) {
+            if ($interactive && $options{'CONFIRM'}) {
                 print "Install package '$package?' (y/N): ";
                 next unless <> =~ /^[yY]/;
             }
-            print "Installing package '$package'...\n";
+            print "Retrieving package '$package'...\n";
             if(!InstallPackage("package" => $package, "location" => $location)) {
                 print "Error installing package '$package': $PPM::PPMERR\n";
             }
@@ -272,7 +252,7 @@ sub more
     if (++$$lines >= $options{'MORE'}) {
         print $moremsg;
         $_ = <>;
-        $$lines = $_ eq "q\n" ? -1 : 1;
+        $$lines = 1;
     }
 }
 
@@ -304,8 +284,7 @@ sub print_formatted
     unless ($options{'VERBOSE'}) {
         foreach $package (sort keys %summary) {
             print "$package\n";
-            &more(\$lines) if $options{'MORE'} && $interactive;
-            last if $lines == -1;
+            &more(\$lines) if $options{'MORE'};
         }
         return;
     }
@@ -340,8 +319,7 @@ sub print_formatted
         write;
         $diff -= $-;
         $lines += ($diff - 1) if $diff > 1;
-        &more(\$lines) if $options{'MORE'} && $interactive;
-        last if $lines == -1;
+        &more(\$lines) if $options{'MORE'};
     }
 }
 
@@ -354,9 +332,6 @@ sub set
             "be confirmed.\n";
         print "Temporary files will " . ($options{'CLEAN'} ? "" : "not ") .
             "be deleted.\n";
-        print "Download status will " . (($options{'DOWNLOADSTATUS'} > 0) ?
-            "be updated every $options{'DOWNLOADSTATUS'} bytes.\n" : 
-            "not be updated.\n");
         print "Case-" . ($options{'IGNORECASE'} ? "in" : "") . 
             "sensitive searches will be performed.\n";
         print "Package installations will " . 
@@ -371,6 +346,7 @@ sub set
         if (defined $location) { print "Current PPD repository: $location\n"; }
         else {
             print "Current PPD repository paths:\n";
+            my $location;
             foreach $_ (keys %repositories) {
                 print "\t$_: $repositories{$_}\n";
             }
@@ -445,14 +421,6 @@ sub set
             print "Temporary files will " . ($options{'CLEAN'} ? "" : "not ") . 
                 "be deleted.\n";
         }
-        elsif (command($option, "|downloadstatus")) {
-            print "Numeric value must be given.\n" and return 1
-                unless (defined $value && $value =~ /^\d+$/);
-            $options{'DOWNLOADSTATUS'} = $value;
-            print "Download status will " . (($options{'DOWNLOADSTATUS'} > 0) ?
-                "be updated every $options{'DOWNLOADSTATUS'} bytes.\n" : 
-                "not be updated.\n");
-        }
         elsif (command($option, "|more")) {
             print "Numeric value must be given.\n" and return 1
                 unless (defined $value && $value =~ /^\d+$/);
@@ -491,7 +459,7 @@ sub set
 sub search_PPDs
 {
     my %argv = @_;
-    my @locations = $argv{'location'} || $location;
+    my $location = $argv{'location'} || $location;
     my $searchtag = $argv{'searchtag'};
     my $ignorecase = defined $argv{'ignorecase'} ? 
         $argv{'ignorecase'} : $options{'IGNORECASE'};
@@ -506,25 +474,11 @@ sub search_PPDs
     }
 
     my %packages;
-    unless (defined $locations[0]) {
-        my %reps = PPM::ListOfRepositories;
-        @locations = values %reps;
-    }
-    foreach my $loc (@locations) {
-        my %summary;
-
-        # see if the repository has server-side searching
-        if (defined $searchRE && (%summary = ServerSearch('location' => $loc, 
-                'searchRE' => $searchRE, 'searchtag' => $searchtag))) {
-            # XXX: clean this up
-            foreach my $package (keys %{$summary{$loc}}) {
-                $packages{$loc}{$package} = \%{$summary{$loc}{$package}};
-            }
-            next;
-        }
-
+    my %ppds = PPM::RepositoryPackages("location" => $location);
+    foreach my $loc (keys %ppds) {
+        next if $#{$ppds{$loc}} == -1;
         # see if a summary file is available
-        %summary = RepositorySummary("location" => $loc);
+        my %summary = RepositorySummary("location" => $loc);
         if (%summary) {
             foreach my $package (keys %{$summary{$loc}}) {
                 next if (defined $searchtag && 
@@ -535,7 +489,6 @@ sub search_PPDs
             }
         }
         else {
-            my %ppds = PPM::RepositoryPackages("location" => $loc);
             # No summary: oh my, nothing but 'Net
             foreach my $package (@{$ppds{$loc}}) {
                 my %package_details = RepositoryPackageProperties(
@@ -554,14 +507,23 @@ sub search_PPDs
 
 sub verify_packages
 {
-    my %argv = @_;
-    my @packages = @{$argv{'packages'}};
-    my $upgrade = $argv{'upgrade'};
-    my $force = $argv{'force'};
-    my $location = $argv{'location'} || $location;
+    my (%argv) = @_;
+    my ($arg, @packages, $upgrade, $force);
+    my $location = $location;
+    foreach $arg (keys %argv) {
+        if ($arg eq 'packages') { @packages = @{$argv{$arg}}; }
+        if ($arg eq 'location') { $location = $argv{$arg}; }
+        if ($arg eq 'upgrade') { $upgrade = $argv{$arg}; }
+        if ($arg eq 'force') { $force = $argv{$arg}; }
+    }
     unless ($packages[0]) {
-        my %info = QueryInstalledPackages();
-        @packages = sort keys %info;
+        my ($i, %info);
+
+        @packages = ();
+        %info = QueryInstalledPackages();
+        foreach $i (keys %info) {
+            push @packages, $i;
+        }
     }
 
     my $package = shift @packages;
@@ -580,8 +542,7 @@ sub verify_packages
             }
         }
         else {
-            # Couldn't find a PPD to compare it with.
-            print "Package \'$package\' is up to date.\n";
+#            print "Error verifying $package: $PPM::PPMERR\n";
         }
         $package = shift @packages;
     }
@@ -589,88 +550,14 @@ sub verify_packages
 
 sub genconfig
 {
-  my $repositories =
-    {'5.6' => {
-	       'ActiveState' =>
-	       {location => 'http://ppm.ActiveState.com/cgibin/PPM/ppmserver.pl?urn:/PPMServer',
-		summaryfile => 'fetch_summary',
-	       },
-	       'Bribes' =>
-	       {location => 'http://www.bribes.org/perl/ppm',
-		summaryfile => 'searchsummary.ppm',
-	       },
-	       'UWinnipeg' =>
-	       {location => 'http://theoryx5.uwinnipeg.ca/cgi-bin/ppmserver?urn:/PPMServer',
-		summaryfile => 'fetch_summary',
-	       },
-	      },
-     '5.8' => {
-	       'ActiveState' =>
-	       {location => 'http://ppm.activestate.com/PPMPackages/5.8-windows',
-		summaryfile => 'searchsummary.ppm',
-	       },
-	       'Bribes' =>
-	       {location => 'http://www.bribes.org/perl/ppm',
-		summaryfile => 'searchsummary.ppm',
-	       },
-	       'UWinnipeg' =>
-	       {location => 'http://theoryx5.uwinnipeg.ca/ppms',
-		summaryfile => 'searchsummary.ppm',
-	       },
-	       'Trouchelle' =>
-	       {location => 'http://trouchelle.com/ppm',
-		summaryfile => 'searchsummary.ppm',
-	       },
-	      },
-     '5.10' => {
-		'ActiveState' =>
-		{location => 'http://ppm.activestate.com/PPMPackages/5.10-windows',
-		 summaryfile => 'searchsummary.ppm',
-		},
-		'Bribes' =>
-		{location => 'http://www.bribes.org/perl/ppm',
-		 summaryfile => 'searchsummary.ppm',
-		},
-		'UWinnipeg' =>
-		{location => 'http://cpan.uwinnipeg.ca/PPMPackages/10xx',
-		 summaryfile => 'searchsummary.ppm',
-		},
-		'Trouchelle' =>
-		{location => 'http://trouchelle.com/ppm10',
-		 summaryfile => 'package.xml',
-		},
-	       },
-    };
-   my ($perl_version);
- PERLV: {
-     ($] < 5.008) and do {
-       $perl_version = '5.6';
-       last PERLV;
-     };
-     ($] < 5.01) and do {
-       $perl_version = '5.8';
-       last PERLV;
-     };
-     $perl_version = '5.10';
-   }
-   my $reps = $repositories->{$perl_version};
-  my $PerlDir = $Config{'prefix'};
-
+my $PerlDir = $Config{'prefix'};
 print <<"EOF";
 <PPMCONFIG>
-    <PPMVER>2,1,8,0</PPMVER>
+    <PPMVER>2,1,0,0</PPMVER>
     <PLATFORM CPU="x86" OSVALUE="$Config{'osname'}" OSVERSION="0,0,0,0" />
-    <OPTIONS BUILDDIR="$ENV{'TEMP'}" CLEAN="1" CONFIRM="1" DOWNLOADSTATUS="16384" FORCEINSTALL="1" IGNORECASE="1" MORE="0" ROOT="$PerlDir" TRACE="0" TRACEFILE="PPM.LOG" VERBOSE="1" />
-EOF
-  foreach my $name(sort keys %$reps) {
-    my $loc = $reps->{$name}->{location};
-    my $sf = $reps->{$name}->{summaryfile};
-    print << "EOF";
-    <REPOSITORY LOCATION="$loc" NAME="$name" SUMMARYFILE="$sf" />
-EOF
-  }
-  print <<"EOF";
-    <PPMPRECIOUS>Compress-Zlib;Archive-Tar;Digest-MD5;File-CounterFile;Font-AFM;HTML-Parser;HTML-Tree;MIME-Base64;URI;XML-Element;libwww-perl;XML-Parser;SOAP-Lite;PPM;libnet;libwin32</PPMPRECIOUS>
+    <OPTIONS BUILDDIR="$ENV{'TEMP'}" CLEAN="1" CONFIRM="1" FORCEINSTALL="1" IGNORECASE="1" MORE="0" ROOT="$PerlDir" TRACE="0" TRACEFILE="PPM.LOG" VERBOSE="1" />
+    <REPOSITORY LOCATION="soap://www.ActiveState.com/cgibin/SOAP/ppmserver.plex?class=PPM::SOAPServer" NAME="ActiveState Package Repository" SUMMARYFILE="fetch_summary"/>
+    <PPMPRECIOUS>Compress-Zlib;Archive-Tar;Digest-MD5;File-CounterFile;Font-AFM;HTML-Parser;HTML-Tree;MIME-Base64;URI;XML-Element;libwww-perl;XML-Parser;SOAP;PPM;libnet;libwin32</PPMPRECIOUS>
 </PPMCONFIG>
 EOF
 }
@@ -813,19 +700,15 @@ See also: 'case' option.
 =item Error Recovery
 
  ppm genconfig
- ppm getconfig
 
-The genconfig command will print a valid PPM config file (ppm.xml) to STDOUT.
-This can be useful if the PPM config file ever gets damaged leaving PPM
+This command will print a valid PPM config file (ppm.xml) to STDOUT.  This 
+can be useful if the PPM config file ever gets damaged leaving PPM
 unusable.
 
 If required, this command should be run from a shell prompt:
 
     C:\Perl\site\lib> ppm genconfig > ppm.xml
 
-The getconfig command prints the location of the PPM configuration file
-used at PPM startup.
-
 =item Options
 
  ppm set [option value]
@@ -853,12 +736,6 @@ Available options:
           If one of '1' or '0' is not specified, the current
           setting is toggled.
 
-    downloadstatus NUMBER
-        - If non-zero, updates the download status after each NUMBER 
-          of bytes transferred during an 'install'.  This can be
-          reassuring when installing a large package (e.g. Tk) over
-          a low-speed connection.
-
     force_install [1|0]
         - Continue installing a package even if a dependency cannot
           be installed.
@@ -894,8 +771,6 @@ Available options:
         - Display additional package information for 'query' and
           'search' commands.
 
-=back
-
 =head1 EXAMPLES
 
 =over 4
@@ -978,7 +853,7 @@ directory, and upgrades to a newer version if available.
 Forces verification and reinstalls every installed package on the system, 
 using upgrade locations specified in the PPM data file.
 
-=item ppm search --location=http://ppm.ActiveState.com/PPMpackages/5.6
+=item ppm search --location=http://www.ActiveState.com/packages
 
 Displays the packages with PPD files available at the specified location.
 
@@ -1030,21 +905,10 @@ in the current directory.
 
 =head1 AUTHOR
 
-Murray Nesbitt, E<lt>F<murray@cpan.org>E<gt>
+Murray Nesbitt, E<lt>F<murray@ActiveState.com>E<gt>
 
 =head1 CREDITS
 
-=over 4
-
-=item *
-
-The "geek-pit" at ActiveState.
-
-=item *
-
-Paul Kulchenko for his SOAP-Lite package, and for his enthusiastic
-assistance in getting PPM to work with SOAP-Lite.
-
-=back
+Thanks to my colleague and friend Jan Dubois E<lt>F<jand@ActiveState.com>E<gt>.
 
 =cut
